﻿Public Enum LoggingProvider
   SystemDiagnostics
   MyApplicationLogger
   Log4net
End Enum

Public Class Logger

   Private Shared _loggingProvider As Nullable(Of LoggingProvider)
   Private Shared ReadOnly _logger As ILogger

   Shared Sub New()
      _logger = LoggerFactory.CreateLogger()
   End Sub

   Private Shared ReadOnly Property Logger() As ILogger
      Get
         Return _logger
      End Get
   End Property

   Public Shared ReadOnly Property Provider() As LoggingProvider
      Get
         If Not _loggingProvider.HasValue Then
            _loggingProvider = GetLoggingProviderFromString(System.Configuration.ConfigurationManager.AppSettings("useLogger"))
         End If

         Return _loggingProvider.Value
      End Get
   End Property

   Public Shared Sub Log(ByVal info As String)
      Logger.Log(info)
   End Sub

   Public Shared Sub Log(ByVal exception As Exception)
      Logger.Log(exception)
   End Sub

   Public Shared Sub LogServiceInvocation(ByVal service As Object, ByVal message As String, Optional ByVal parameterInfo As String = Nothing)
      Logger.LogServiceInvocation(service, message, parameterInfo)
   End Sub

   Public Shared Sub LogServiceReturn(ByVal service As Object, ByVal message As String, Optional ByVal returnInfo As String = Nothing)
      Logger.LogServiceReturn(service, message, returnInfo)
   End Sub

   Private Shared Function GetLoggingProviderFromString(ByVal ProviderAsString As String) As LoggingProvider
      For Each value In [Enum].GetValues(GetType(LoggingProvider))
         If value.ToString() = ProviderAsString Then
            Return CType(value, LoggingProvider)
         End If
      Next

      Throw New ArgumentOutOfRangeException("ProviderAsString")
   End Function
End Class
