﻿Public MustInherit Class LoggerBase
   Implements ILogger

#Region "ILogger Implementation"

   Public MustOverride Sub Log(ByVal info As String) Implements ILogger.Log
   Public MustOverride Sub Log(ByVal exception As System.Exception) Implements ILogger.Log
   Public MustOverride Sub LogServiceInvocation(ByVal service As Object, ByVal message As String, ByVal parameterInfo As String) Implements ILogger.LogServiceInvocation
   Public MustOverride Sub LogServiceReturn(ByVal service As Object, ByVal message As String, ByVal returnInfo As String) Implements ILogger.LogServiceReturn

#End Region

#Region "Protected Methoden"

   Protected Function GetExceptionInfoRecursive(ByVal exception As Exception) As String
      Dim info = GetExceptionInfo(exception)

      exception = exception.InnerException
      Do While (exception IsNot Nothing)
         info &= "InnerException:" & Environment.NewLine & _
                  GetExceptionInfo(exception)
         exception = exception.InnerException
      Loop

      Return info
   End Function

   Protected Function GetExceptionInfo(ByVal exception As Exception) As String
      Return "Message:" & Environment.NewLine & _
            exception.Message & Environment.NewLine & _
            "StackTrace:" & Environment.NewLine & _
            exception.StackTrace
   End Function

   Protected Function GetLogServiceInvocationInfo(ByVal service As Object, ByVal message As String, ByVal parameterInfo As String) As String
      Dim msg = String.Format("Invoking message {0} on {1}", message, service.GetType().Name)
      If Not String.IsNullOrEmpty(parameterInfo) Then
         msg &= String.Format(" with parameters: ""{0}""", parameterInfo)
      End If

      Return msg
   End Function

   Protected Function GetLogServiceReturnInfo(ByVal service As Object, ByVal message As String, ByVal returnInfo As String) As String
      Dim msg = String.Format("Returning from message {0} on {1}", message, service.GetType().Name)
      If Not String.IsNullOrEmpty(returnInfo) Then
         msg &= String.Format(" with ""{0}""", returnInfo)
      End If

      Return msg
   End Function

#End Region

End Class
