﻿<Assembly: log4net.Config.XmlConfigurator(Watch:=True)> 
Public Class MainForm

#Region "Event Handler"

   Private Sub MainForm_Load(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.Load
      AddHandler My.Application.Shutdown, AddressOf MyApplication_ShutDown

      LoadSettings()
      ShowLogProviderInfo()
   End Sub

   Private Sub MainForm_DoubleClick(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.DoubleClick
      If ColorDialog.ShowDialog(Me) = Windows.Forms.DialogResult.OK Then
         Me.BackColor = ColorDialog.Color
      End If
   End Sub

   Private Sub MainForm_BackColorChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles Me.BackColorChanged
      My.Settings.Standardfarbe = Me.BackColor
   End Sub

   Private Sub btnKundenSuchen_Click(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles btnKundenSuchen.Click
      SearchKunde()
   End Sub

   Private Sub txtKundenNr_KeyPress(ByVal sender As System.Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles txtKundenNr.KeyPress
      If e.KeyChar = Chr(13) Then
         SearchKunde()
      End If
   End Sub

#End Region

#Region "Private Methods"

   Private Sub EmptyFields()
      Me.KundeView.Kunde = Nothing
   End Sub

   Private Sub SearchKunde()
      Logger.Log(String.Format("Auf Kundensuche mit ""{0}"" geklickt.", txtKundenNr.Text))

      Dim kundenId As Nullable(Of Integer) = GetEnteredKundenId()

      If kundenId.HasValue Then
         EmptyFields()
         LoadKunde(kundenId.Value)
      End If
   End Sub

   Private Sub LoadKunde(ByVal KundenId As Integer)
      Try
         ShowInfo("Kunde wird geladen...")
         Dim kunde = ClientFacade.KundenFacade.GetPrivatKundeByKundenNr(KundenId)

         KundeView.Kunde = kunde
      Catch ex As Exception
         Logger.Log(ex)
         MessageBox.Show(ex.Message, Application.ProductName, _
                         MessageBoxButtons.OK, MessageBoxIcon.Error)
      Finally
         HideInfo()
      End Try
   End Sub

   Private Function GetEnteredKundenId() As Nullable(Of Integer)
      Dim kundenNr As Integer

      If Integer.TryParse(txtKundenNr.Text, kundenNr) Then
         Return kundenNr
      End If

      Dim msg = String.Format("""{0}"" ist keine gültige KundenNr.", txtKundenNr.Text)
      Logger.Log(New Exception(msg))

      Return Nothing
   End Function

   Private Sub ShowInfo(ByVal info As String)
      With lblInfo
         .Text = info
         .Visible = True
      End With
   End Sub

   Private Sub HideInfo()
      lblInfo.Visible = False
   End Sub

   Private Sub LoadSettings()
      Me.BackColor = My.Settings.Standardfarbe
      Me.Text = My.Settings.Anwendungstitel
   End Sub

   Private Sub ShowLogProviderInfo()
      Me.lblLoggerInfo.Text = String.Format("Aktueller Logging Provider: {0}", Logger.Provider)
   End Sub

   Private Sub MyApplication_ShutDown(ByVal Sender As Object, ByVal e As EventArgs)
      My.Settings.Save()
   End Sub

#End Region

End Class
